=== modified file 'include/my_global.h'
--- include/my_global.h	2008-07-05 22:08:52 +0000
+++ include/my_global.h	2008-07-05 23:05:08 +0000
@@ -393,7 +393,7 @@
 #define set_if_smaller(a,b) do { if ((a) > (b)) (a)=(b); } while(0)
 #define test_all_bits(a,b) (((a) & (b)) == (b))
 #define set_bits(type, bit_count) (sizeof(type)*8 <= (bit_count) ? ~(type) 0 : ((((type) 1) << (bit_count)) - (type) 1))
-#define array_elements(A) ((uint) (sizeof(A)/sizeof(A[0])))
+#define array_elements(A) ((uint32_t) (sizeof(A)/sizeof(A[0])))
 #ifndef HAVE_RINT
 #define rint(A) floor((A)+(((A) < 0)? -0.5 : 0.5))
 #endif

=== modified file 'include/my_sys.h'
--- include/my_sys.h	2008-07-05 10:49:39 +0000
+++ include/my_sys.h	2008-07-05 23:05:08 +0000
@@ -785,7 +785,6 @@
 extern ha_checksum my_checksum(ha_checksum crc, const uchar *mem,
                                size_t count);
 extern void my_sleep(ulong m_seconds);
-extern ulong crc32(ulong crc, const uchar *buf, uint len);
 extern uint my_set_max_open_files(uint files);
 void my_free_open_file_info(void);
 

=== modified file 'sql/field.h'
--- sql/field.h	2008-07-05 22:08:52 +0000
+++ sql/field.h	2008-07-05 23:05:08 +0000
@@ -49,7 +49,9 @@
   void operator=(Field &);
 public:
   static void *operator new(size_t size) {return sql_alloc(size); }
-  static void operator delete(void *ptr_arg, size_t size) { TRASH(ptr_arg, size); }
+  static void operator delete(void *ptr_arg __attribute__((__unused__)),
+                              size_t size __attribute__((__unused__)))
+  { TRASH(ptr_arg, size); }
 
   uchar		*ptr;			// Position to field in record
   uchar		*null_ptr;		// Byte where null_bit is
@@ -213,10 +215,12 @@
   virtual enum_field_types type() const =0;
   virtual enum_field_types real_type() const { return type(); }
   inline  int cmp(const uchar *str) { return cmp(ptr,str); }
-  virtual int cmp_max(const uchar *a, const uchar *b, uint max_len)
+  virtual int cmp_max(const uchar *a, const uchar *b,
+                      uint max_len __attribute__((__unused__)))
     { return cmp(a, b); }
   virtual int cmp(const uchar *,const uchar *)=0;
-  virtual int cmp_binary(const uchar *a,const uchar *b, uint32 max_length=~0L)
+  virtual int cmp_binary(const uchar *a,const uchar *b,
+                         uint32  __attribute__((__unused__)) max_length=~0)
   { return memcmp(a,b,pack_length()); }
   virtual int cmp_offset(uint row_offset)
   { return cmp(ptr,ptr+row_offset); }
@@ -224,7 +228,7 @@
   { return cmp_binary(ptr, ptr+row_offset); };
   virtual int key_cmp(const uchar *a,const uchar *b)
   { return cmp(a, b); }
-  virtual int key_cmp(const uchar *str, uint length)
+  virtual int key_cmp(const uchar *str, uint length __attribute__((__unused__)))
   { return cmp(ptr,str); }
   virtual uint decimals() const { return 0; }
   /*
@@ -313,9 +317,11 @@
     if (null_ptr)
       null_ptr=ADD_TO_PTR(null_ptr,ptr_diff,uchar*);
   }
-  virtual void get_image(uchar *buff, uint length, CHARSET_INFO *cs)
+  virtual void get_image(uchar *buff, uint length,
+                         CHARSET_INFO *cs __attribute__((__unused__)))
     { memcpy(buff,ptr,length); }
-  virtual void set_image(const uchar *buff,uint length, CHARSET_INFO *cs)
+  virtual void set_image(const uchar *buff,uint length,
+                         CHARSET_INFO *cs __attribute__((__unused__)))
     { memcpy(ptr,buff,length); }
 
 
@@ -345,7 +351,8 @@
       Number of copied bytes (excluding padded zero bytes -- see above).
   */
 
-  virtual uint get_key_image(uchar *buff, uint length, imagetype type)
+  virtual uint get_key_image(uchar *buff, uint length,
+                             imagetype type __attribute__((__unused__)))
   {
     get_image(buff, length, &my_charset_bin);
     return length;
@@ -417,16 +424,19 @@
   {
     return unpack(to, from, max_length, low_byte_first);
   }
-  virtual uint packed_col_length(const uchar *to, uint length)
+  virtual uint packed_col_length(const uchar *to __attribute__((__unused__)),
+                                 uint length)
   { return length;}
   virtual uint max_packed_col_length(uint max_length)
   { return max_length;}
 
-  virtual int pack_cmp(const uchar *a,const uchar *b, uint key_length_arg,
-                       my_bool insert_or_update)
+  virtual int pack_cmp(const uchar *a,const uchar *b,
+                       uint key_length_arg __attribute__((__unused__)),
+                       my_bool insert_or_update __attribute__((__unused__)))
   { return cmp(a,b); }
-  virtual int pack_cmp(const uchar *b, uint key_length_arg,
-                       my_bool insert_or_update)
+  virtual int pack_cmp(const uchar *b,
+                       uint key_length_arg __attribute__((__unused__)),
+                       my_bool insert_or_update __attribute__((__unused__)))
   { return cmp(ptr,b); }
   uint offset(uchar *record)
   {
@@ -439,10 +449,12 @@
   virtual CHARSET_INFO *charset(void) const { return &my_charset_bin; }
   virtual CHARSET_INFO *sort_charset(void) const { return charset(); }
   virtual bool has_charset(void) const { return FALSE; }
-  virtual void set_charset(CHARSET_INFO *charset_arg) { }
+  virtual void set_charset(CHARSET_INFO *charset_arg __attribute__((__unused__)))
+  { }
   virtual enum Derivation derivation(void) const
   { return DERIVATION_IMPLICIT; }
-  virtual void set_derivation(enum Derivation derivation_arg) { }
+  virtual void set_derivation(enum Derivation derivation_arg __attribute__((__unused__)))
+  { }
   bool set_warning(MYSQL_ERROR::enum_warning_level, unsigned int code,
                    int cuted_increment);
   void set_datetime_warning(MYSQL_ERROR::enum_warning_level, uint code, 
@@ -549,7 +561,7 @@
 
    @returns 0 no bytes written.
 */
-  virtual int do_save_field_metadata(uchar *metadata_ptr)
+  virtual int do_save_field_metadata(uchar *metadata_ptr __attribute__((__unused__)))
   { return 0; }
 };
 
@@ -773,14 +785,16 @@
   uint32 max_display_length() { return 4; }
 
   virtual uchar *pack(uchar* to, const uchar *from,
-                      uint max_length, bool low_byte_first)
+                      uint max_length __attribute__((__unused__)),
+                      bool low_byte_first __attribute__((__unused__)))
   {
     *to= *from;
     return to + 1;
   }
 
   virtual const uchar *unpack(uchar* to, const uchar *from,
-                              uint param_data, bool low_byte_first)
+                              uint param_data __attribute__((__unused__)),
+                              bool low_byte_first __attribute__((__unused__)))
   {
     *to= *from;
     return from + 1;
@@ -822,7 +836,8 @@
   uint32 max_display_length() { return 6; }
 
   virtual uchar *pack(uchar* to, const uchar *from,
-                      uint max_length, bool low_byte_first)
+                      uint max_length __attribute__((__unused__)),
+                      bool low_byte_first __attribute__((__unused__)))
   {
     int16 val;
 #ifdef WORDS_BIGENDIAN
@@ -842,7 +857,8 @@
   }
 
   virtual const uchar *unpack(uchar* to, const uchar *from,
-                              uint param_data, bool low_byte_first)
+                              uint param_data __attribute__((__unused__)),
+                              bool low_byte_first __attribute__((__unused__)))
   {
     int16 val;
 #ifdef WORDS_BIGENDIAN
@@ -937,7 +953,8 @@
   void sql_type(String &str) const;
   uint32 max_display_length() { return MY_INT32_NUM_DECIMAL_DIGITS; }
   virtual uchar *pack(uchar* to, const uchar *from,
-                      uint max_length, bool low_byte_first)
+                      uint max_length __attribute__((__unused__)),
+                      bool low_byte_first __attribute__((__unused__)))
   {
     int32 val;
 #ifdef WORDS_BIGENDIAN
@@ -957,7 +974,8 @@
   }
 
   virtual const uchar *unpack(uchar* to, const uchar *from,
-                              uint param_data, bool low_byte_first)
+                              uint param_data __attribute__((__unused__)),
+                              bool low_byte_first __attribute__((__unused__)))
   {
     int32 val;
 #ifdef WORDS_BIGENDIAN
@@ -1017,7 +1035,8 @@
   bool can_be_compared_as_longlong() const { return TRUE; }
   uint32 max_display_length() { return 20; }
   virtual uchar *pack(uchar* to, const uchar *from,
-                      uint max_length, bool low_byte_first)
+                      uint max_length __attribute__((__unused__)),
+                      bool low_byte_first __attribute__((__unused__)))
   {
     int64 val;
 #ifdef WORDS_BIGENDIAN
@@ -1037,7 +1056,8 @@
   }
 
   virtual const uchar *unpack(uchar* to, const uchar *from,
-                              uint param_data, bool low_byte_first)
+                              uint param_data __attribute__((__unused__)),
+                              bool low_byte_first __attribute__((__unused__)))
   {
     int64 val;
 #ifdef WORDS_BIGENDIAN
@@ -1144,19 +1164,31 @@
 	       unireg_check_arg, field_name_arg, cs)
     {}
   enum_field_types type() const { return MYSQL_TYPE_NULL;}
-  int  store(const char *to, uint length, CHARSET_INFO *cs)
-  { null[0]=1; return 0; }
-  int store(double nr)   { null[0]=1; return 0; }
-  int store(longlong nr, bool unsigned_val) { null[0]=1; return 0; }
-  int store_decimal(const my_decimal *d)  { null[0]=1; return 0; }
-  int reset(void)	  { return 0; }
-  double val_real(void)		{ return 0.0;}
-  longlong val_int(void)	{ return 0;}
+  int  store(const char *to __attribute__((__unused__)),
+             uint length __attribute__((__unused__)),
+             CHARSET_INFO *cs __attribute__((__unused__)))
+  { null[0]=1; return 0; }
+  int store(double nr __attribute__((__unused__)))
+  { null[0]=1; return 0; }
+  int store(longlong nr __attribute__((__unused__)),
+            bool unsigned_val __attribute__((__unused__)))
+  { null[0]=1; return 0; }
+  int store_decimal(const my_decimal *d __attribute__((__unused__)))
+  { null[0]=1; return 0; }
+  int reset(void)
+  { return 0; }
+  double val_real(void)
+  { return 0.0;}
+  longlong val_int(void)
+  { return 0;}
   my_decimal *val_decimal(my_decimal *) { return 0; }
-  String *val_str(String *value,String *value2)
+  String *val_str(String *value __attribute__((__unused__)),
+                  String *value2)
   { value2->length(0); return value2;}
-  int cmp(const uchar *a, const uchar *b) { return 0;}
-  void sort_string(uchar *buff, uint length)  {}
+  int cmp(const uchar *a __attribute__((__unused__)),
+          const uchar *b __attribute__((__unused__))) { return 0;}
+  void sort_string(uchar *buff __attribute__((__unused__)),
+                   uint length __attribute__((__unused__)))  {}
   uint32 pack_length() const { return 0; }
   void sql_type(String &str) const;
   uint size_of() const { return sizeof(*this); }
@@ -1763,7 +1795,9 @@
   { return (field_metadata & 0x00ff); }
   uint row_pack_length() { return pack_length(); }
   virtual bool zero_pack() const { return 0; }
-  bool optimize_range(uint idx, uint part) { return 0; }
+  bool optimize_range(uint idx __attribute__((__unused__)),
+                      uint part __attribute__((__unused__)))
+  { return 0; }
   bool eq_def(Field *field);
   bool has_charset(void) const { return TRUE; }
   /* enum and set are sorted as integers */
@@ -1840,8 +1874,8 @@
   virtual bool str_needs_quotes() { return TRUE; }
   my_decimal *val_decimal(my_decimal *);
   int cmp(const uchar *a, const uchar *b)
-  { 
-    DBUG_ASSERT(ptr == a);
+  {
+    assert(ptr == a);
     return Field_bit::key_cmp(b, bytes_in_rec+test(bit_len));
   }
   int cmp_binary_offset(uint row_offset)
@@ -1851,8 +1885,9 @@
   { return cmp_binary((uchar *) a, (uchar *) b); }
   int key_cmp(const uchar *str, uint length);
   int cmp_offset(uint row_offset);
-  void get_image(uchar *buff, uint length, CHARSET_INFO *cs)
-  { get_key_image(buff, length, itRAW); }   
+  void get_image(uchar *buff, uint length,
+                 CHARSET_INFO *cs __attribute__((__unused__)))
+  { get_key_image(buff, length, itRAW); }
   void set_image(const uchar *buff,uint length, CHARSET_INFO *cs)
   { Field_bit::store((char *) buff, length, cs); }
   uint get_key_image(uchar *buff, uint length, imagetype type);

=== modified file 'sql/handler.h'
--- sql/handler.h	2008-07-04 22:54:17 +0000
+++ sql/handler.h	2008-07-05 23:05:08 +0000
@@ -910,7 +910,8 @@
   }
 private:
   /* Function primitive that is called prior to locking tables */
-  virtual void do_prelock(TABLE **tables, uint count)
+  virtual void do_prelock(TABLE **tables __attribute__((__unused__)),
+                          uint count __attribute__((__unused__)))
   {
     /* Default is to do nothing */
   }
@@ -923,7 +924,8 @@
 
      @return Error code or zero.
    */
-  virtual int do_postlock(TABLE **tables, uint count)
+  virtual int do_postlock(TABLE **tables __attribute__((__unused__)),
+                          uint count __attribute__((__unused__)))
   {
     return 0;                           /* Default is to do nothing */
   }
@@ -1396,9 +1398,10 @@
     table_share= share;
   }
   /* Estimates calculation */
-  virtual double scan_time()
+  virtual double scan_time(void)
   { return ulonglong2double(stats.data_file_length) / IO_SIZE + 2; }
-  virtual double read_time(uint index, uint ranges, ha_rows rows)
+  virtual double read_time(uint index __attribute__((__unused__)),
+                           uint ranges, ha_rows rows)
   { return rows2double(ranges+rows); }
 
   virtual double index_only_read_time(uint keynr, double records);
@@ -1460,7 +1463,8 @@
   */
   virtual enum row_type get_row_type() const { return ROW_TYPE_NOT_USED; }
 
-  virtual const char *index_type(uint key_number) { DBUG_ASSERT(0); return "";}
+  virtual const char *index_type(uint key_number __attribute__((__unused__)))
+  { DBUG_ASSERT(0); return "";}
 
 
   /**
@@ -1495,7 +1499,7 @@
     @retval  0           Success
     @retval  >0          Error code
   */
-  virtual int exec_bulk_update(uint *dup_key_found)
+  virtual int exec_bulk_update(uint *dup_key_found __attribute__((__unused__)))
   {
     DBUG_ASSERT(FALSE);
     return HA_ERR_WRONG_COMMAND;
@@ -1538,15 +1542,17 @@
   virtual int index_read_idx_map(uchar * buf, uint index, const uchar * key,
                                  key_part_map keypart_map,
                                  enum ha_rkey_function find_flag);
-  virtual int index_next(uchar * buf)
-   { return  HA_ERR_WRONG_COMMAND; }
-  virtual int index_prev(uchar * buf)
-   { return  HA_ERR_WRONG_COMMAND; }
-  virtual int index_first(uchar * buf)
-   { return  HA_ERR_WRONG_COMMAND; }
-  virtual int index_last(uchar * buf)
-   { return  HA_ERR_WRONG_COMMAND; }
-  virtual int index_next_same(uchar *buf, const uchar *key, uint keylen);
+  virtual int index_next(uchar * buf __attribute__((__unused__)))
+   { return  HA_ERR_WRONG_COMMAND; }
+  virtual int index_prev(uchar * buf __attribute__((__unused__)))
+   { return  HA_ERR_WRONG_COMMAND; }
+  virtual int index_first(uchar * buf __attribute__((__unused__)))
+   { return  HA_ERR_WRONG_COMMAND; }
+  virtual int index_last(uchar * buf __attribute__((__unused__)))
+   { return  HA_ERR_WRONG_COMMAND; }
+  virtual int index_next_same(uchar *buf __attribute__((__unused__)),
+                              const uchar *key __attribute__((__unused__)),
+                              uint keylen __attribute__((__unused__)));
   /**
      @brief
      The following functions works like index_read, but it find the last
@@ -1566,11 +1572,14 @@
   int compare_key2(key_range *range);
   virtual int ft_init() { return HA_ERR_WRONG_COMMAND; }
   void ft_end() { ft_handler=NULL; }
-  virtual FT_INFO *ft_init_ext(uint flags, uint inx,String *key)
+  virtual FT_INFO *ft_init_ext(uint flags __attribute__((__unused__)),
+                               uint inx __attribute__((__unused__)),
+                               String *key __attribute__((__unused__)))
     { return NULL; }
-  virtual int ft_read(uchar *buf) { return HA_ERR_WRONG_COMMAND; }
-  virtual int rnd_next(uchar *buf)=0;
-  virtual int rnd_pos(uchar * buf, uchar *pos)=0;
+  virtual int ft_read(uchar *buf __attribute__((__unused__))) { return HA_ERR_WRONG_COMMAND; }
+  virtual int rnd_next(uchar *buf __attribute__((__unused__)))=0;
+  virtual int rnd_pos(uchar * buf __attribute__((__unused__)),
+                      uchar *pos __attribute__((__unused__)))=0;
   /**
     One has to use this method when to find
     random position by record as the plain
@@ -1583,19 +1592,24 @@
     The following function is only needed for tables that may be temporary
     tables during joins.
   */
-  virtual int restart_rnd_next(uchar *buf, uchar *pos)
-    { return HA_ERR_WRONG_COMMAND; }
-  virtual int rnd_same(uchar *buf, uint inx)
-    { return HA_ERR_WRONG_COMMAND; }
-  virtual ha_rows records_in_range(uint inx, key_range *min_key, key_range *max_key)
+  virtual int restart_rnd_next(uchar *buf __attribute__((__unused__)),
+                               uchar *pos __attribute__((__unused__)))
+    { return HA_ERR_WRONG_COMMAND; }
+  virtual int rnd_same(uchar *buf __attribute__((__unused__)),
+                       uint inx __attribute__((__unused__)))
+    { return HA_ERR_WRONG_COMMAND; }
+  virtual ha_rows records_in_range(uint inx __attribute__((__unused__)),
+                                   key_range *min_key __attribute__((__unused__)),
+                                   key_range *max_key __attribute__((__unused__)))
     { return (ha_rows) 10; }
   virtual void position(const uchar *record)=0;
   virtual int info(uint)=0; // see my_base.h for full description
-  virtual uint32 calculate_key_hash_value(Field **field_array)
+  virtual uint32 calculate_key_hash_value(Field **field_array __attribute__((__unused__)))
   { DBUG_ASSERT(0); return 0; }
-  virtual int extra(enum ha_extra_function operation)
+  virtual int extra(enum ha_extra_function operation __attribute__((__unused__)))
   { return 0; }
-  virtual int extra_opt(enum ha_extra_function operation, ulong cache_size)
+  virtual int extra_opt(enum ha_extra_function operation,
+                        ulong cache_size __attribute__((__unused__)))
   { return extra(operation); }
 
   /**
@@ -1618,8 +1632,10 @@
     the last committed row value under the cursor.
   */
   virtual void try_semi_consistent_read(bool) {}
-  virtual void unlock_row() {}
-  virtual int start_stmt(THD *thd, thr_lock_type lock_type) {return 0;}
+  virtual void unlock_row(void) {}
+  virtual int start_stmt(THD *thd __attribute__((__unused__)),
+                         thr_lock_type lock_type __attribute__((__unused__)))
+  {return 0;}
   virtual void get_auto_increment(uint64_t offset, uint64_t increment,
                                   uint64_t nb_desired_values,
                                   uint64_t *first_value,
@@ -1645,16 +1661,18 @@
       insert_id_for_cur_row;
   }
 
-  virtual void update_create_info(HA_CREATE_INFO *create_info) {}
-  int check_old_types();
-  virtual int assign_to_keycache(THD* thd, HA_CHECK_OPT* check_opt)
+  virtual void update_create_info(HA_CREATE_INFO *create_info __attribute__((__unused__))) {}
+  int check_old_types(void);
+  virtual int assign_to_keycache(THD* thd __attribute__((__unused__)),
+                                 HA_CHECK_OPT* check_opt __attribute__((__unused__)))
   { return HA_ADMIN_NOT_IMPLEMENTED; }
   /* end of the list of admin commands */
 
   virtual int indexes_are_disabled(void) {return 0;}
   virtual char *update_table_comment(const char * comment)
   { return (char*) comment;}
-  virtual void append_create_info(String *packet) {}
+  virtual void append_create_info(String *packet __attribute__((__unused__)))
+  {}
   /**
       If index == MAX_KEY then a check for table is made and if index <
       MAX_KEY then a check is made if the table has foreign keys and if
@@ -1665,21 +1683,22 @@
     @retval   TRUE            Foreign key defined on table or index
     @retval   FALSE           No foreign key defined
   */
-  virtual bool is_fk_defined_on_table_or_index(uint index)
+  virtual bool is_fk_defined_on_table_or_index(uint index __attribute__((__unused__)))
   { return FALSE; }
-  virtual char* get_foreign_key_create_info()
+  virtual char* get_foreign_key_create_info(void)
   { return(NULL);}  /* gets foreign key create string from InnoDB */
   /* gets tablespace name from handler */
-  const char* get_tablespace_name();
+  const char* get_tablespace_name(void);
   /** used in ALTER TABLE; 1 if changing storage engine is allowed */
-  virtual bool can_switch_engines() { return 1; }
+  virtual bool can_switch_engines(void) { return 1; }
   /** used in REPLACE; is > 0 if table is referred by a FOREIGN KEY */
-  virtual int get_foreign_key_list(THD *thd, List<FOREIGN_KEY_INFO> *f_key_list)
+  virtual int get_foreign_key_list(THD *thd __attribute__((__unused__)),
+                                   List<FOREIGN_KEY_INFO> *f_key_list __attribute__((__unused__)))
   { return 0; }
   virtual uint referenced_by_foreign_key() { return 0;}
   virtual void init_table_handle_for_HANDLER()
   { return; }       /* prepare InnoDB for HANDLER */
-  virtual void free_foreign_key_create_info(char* str) {}
+  virtual void free_foreign_key_create_info(char* str __attribute__((__unused__))) {}
   /** The following can be called without an open handler */
   virtual const char *table_type() const =0;
   /**
@@ -1695,8 +1714,8 @@
   */
   virtual const char **bas_ext() const =0;
 
-  virtual int get_default_no_partitions(HA_CREATE_INFO *info) { return 1;}
-  virtual bool get_no_parts(const char *name,
+  virtual int get_default_no_partitions(HA_CREATE_INFO *info __attribute__((__unused__))) { return 1;}
+  virtual bool get_no_parts(const char *name __attribute__((__unused__)),
                             uint *no_parts)
   {
     *no_parts= 0;
@@ -1705,12 +1724,15 @@
 
   virtual ulong index_flags(uint idx, uint part, bool all_parts) const =0;
 
-  virtual int add_index(TABLE *table_arg, KEY *key_info, uint num_of_keys)
-  { return (HA_ERR_WRONG_COMMAND); }
-  virtual int prepare_drop_index(TABLE *table_arg, uint *key_num,
-                                 uint num_of_keys)
-  { return (HA_ERR_WRONG_COMMAND); }
-  virtual int final_drop_index(TABLE *table_arg)
+  virtual int add_index(TABLE *table_arg __attribute__((__unused__)),
+                        KEY *key_info __attribute__((__unused__)),
+                        uint num_of_keys __attribute__((__unused__)))
+  { return (HA_ERR_WRONG_COMMAND); }
+  virtual int prepare_drop_index(TABLE *table_arg __attribute__((__unused__)),
+                                 uint *key_num __attribute__((__unused__)),
+                                 uint num_of_keys __attribute__((__unused__)))
+  { return (HA_ERR_WRONG_COMMAND); }
+  virtual int final_drop_index(TABLE *table_arg __attribute__((__unused__)))
   { return (HA_ERR_WRONG_COMMAND); }
 
   uint max_record_length() const
@@ -1721,20 +1743,22 @@
   { return min(MAX_REF_PARTS, max_supported_key_parts()); }
   uint max_key_length() const
   { return min(MAX_KEY_LENGTH, max_supported_key_length()); }
-  uint max_key_part_length() const
+  uint max_key_part_length(void) const
   { return min(MAX_KEY_LENGTH, max_supported_key_part_length()); }
 
-  virtual uint max_supported_record_length() const { return HA_MAX_REC_LENGTH; }
-  virtual uint max_supported_keys() const { return 0; }
-  virtual uint max_supported_key_parts() const { return MAX_REF_PARTS; }
-  virtual uint max_supported_key_length() const { return MAX_KEY_LENGTH; }
-  virtual uint max_supported_key_part_length() const { return 255; }
-  virtual uint min_record_length(uint options) const { return 1; }
+  virtual uint max_supported_record_length(void) const
+  { return HA_MAX_REC_LENGTH; }
+  virtual uint max_supported_keys(void) const { return 0; }
+  virtual uint max_supported_key_parts(void) const { return MAX_REF_PARTS; }
+  virtual uint max_supported_key_length(void) const { return MAX_KEY_LENGTH; }
+  virtual uint max_supported_key_part_length(void) const { return 255; }
+  virtual uint min_record_length(uint options __attribute__((__unused__))) const
+  { return 1; }
 
-  virtual bool low_byte_first() const { return 1; }
-  virtual uint checksum() const { return 0; }
-  virtual bool is_crashed() const  { return 0; }
-  virtual bool auto_repair() const { return 0; }
+  virtual bool low_byte_first(void) const { return 1; }
+  virtual uint checksum(void) const { return 0; }
+  virtual bool is_crashed(void) const  { return 0; }
+  virtual bool auto_repair(void) const { return 0; }
 
 
 #define CHF_CREATE_FLAG 0
@@ -1797,11 +1821,12 @@
         cached
   */
 
-  virtual my_bool register_query_cache_table(THD *thd, char *table_key,
-                                             uint key_length,
-                                             qc_engine_callback
-                                             *engine_callback,
-                                             uint64_t *engine_data)
+  virtual my_bool
+    register_query_cache_table(THD *thd __attribute__((__unused__)),
+                               char *table_key __attribute__((__unused__)),
+                               uint key_length __attribute__((__unused__)),
+                               qc_engine_callback *engine_callback,
+                               uint64_t *engine_data __attribute__((__unused__)))
   {
     *engine_callback= 0;
     return TRUE;
@@ -1846,21 +1871,25 @@
    condition stack.
  */ 
  virtual const COND *cond_push(const COND *cond) { return cond; }
- 
+
  /**
    Pop the top condition from the condition stack of the handler instance.
 
    Pops the top if condition stack, if stack is not empty.
  */
- virtual void cond_pop() { return; }
+ virtual void cond_pop(void) { return; }
 
- virtual Item *idx_cond_push(uint keyno, Item* idx_cond) { return idx_cond; }
+ virtual Item
+   *idx_cond_push(uint keyno __attribute__((__unused__)),
+                  Item* idx_cond __attribute__((__unused__)))
+ { return idx_cond; }
 
  /*
     Part of old fast alter table, to be depricated
   */
- virtual bool check_if_incompatible_data(HA_CREATE_INFO *create_info,
-                                         uint table_changes)
+ virtual bool
+   check_if_incompatible_data(HA_CREATE_INFO *create_info __attribute__((__unused__)),
+                              uint table_changes __attribute__((__unused__)))
  { return COMPATIBLE_DATA_NO; }
 
  /* On-line ALTER TABLE interface */
@@ -1886,12 +1915,13 @@
       The default implementation is implemented to support fast
       alter table (storage engines that support some changes by
       just changing the frm file) without any change in the handler
-      implementation.    
+      implementation.
  */
- virtual int check_if_supported_alter(TABLE *altered_table,
-                                      HA_CREATE_INFO *create_info,
-                                      HA_ALTER_FLAGS *alter_flags,
-                                      uint table_changes)
+ virtual int
+   check_if_supported_alter(TABLE *altered_table __attribute__((__unused__)),
+                            HA_CREATE_INFO *create_info,
+                            HA_ALTER_FLAGS *alter_flags __attribute__((__unused__)),
+                            uint table_changes)
  {
    DBUG_ENTER("check_if_supported_alter");
    if (this->check_if_incompatible_data(create_info, table_changes)
@@ -1913,11 +1943,11 @@
    @retval   0      OK
    @retval   error  error code passed from storage engine
  */
- virtual int alter_table_phase1(THD *thd,
-                                TABLE *altered_table,
-                                HA_CREATE_INFO *create_info,
-                                HA_ALTER_INFO *alter_info,
-                                HA_ALTER_FLAGS *alter_flags)
+ virtual int alter_table_phase1(THD *thd __attribute__((__unused__)),
+                                TABLE *altered_table __attribute__((__unused__)),
+                                HA_CREATE_INFO *create_info __attribute__((__unused__)),
+                                HA_ALTER_INFO *alter_info __attribute__((__unused__)),
+                                HA_ALTER_FLAGS *alter_flags  __attribute__((__unused__)))
  {
    return HA_ERR_UNSUPPORTED;
  }
@@ -1939,11 +1969,11 @@
       this call is to be wrapped with a DDL lock. This is currently NOT
       supported.
  */
- virtual int alter_table_phase2(THD *thd,
-                                TABLE *altered_table,
-                                HA_CREATE_INFO *create_info,
-                                HA_ALTER_INFO *alter_info,
-                                HA_ALTER_FLAGS *alter_flags)
+ virtual int alter_table_phase2(THD *thd  __attribute__((__unused__)),
+                                TABLE *altered_table  __attribute__((__unused__)),
+                                HA_CREATE_INFO *create_info __attribute__((__unused__)),
+                                HA_ALTER_INFO *alter_info __attribute__((__unused__)),
+                                HA_ALTER_FLAGS *alter_flags __attribute__((__unused__)))
  {
    return HA_ERR_UNSUPPORTED;
  }
@@ -1954,7 +1984,8 @@
     @param    thd               The thread handle
     @param    table             The altered table, re-opened
  */
- virtual int alter_table_phase3(THD *thd, TABLE *table)
+ virtual int alter_table_phase3(THD *thd __attribute__((__unused__)),
+                                TABLE *table __attribute__((__unused__)))
  {
    return HA_ERR_UNSUPPORTED;
  }
@@ -2028,7 +2059,9 @@
   */
 
   virtual int open(const char *name, int mode, uint test_if_locked)=0;
-  virtual int index_init(uint idx, bool sorted) { active_index= idx; return 0; }
+  virtual int index_init(uint idx,
+                         bool sorted __attribute__((__unused__)))
+  { active_index= idx; return 0; }
   virtual int index_end() { active_index= MAX_KEY; return 0; }
   /**
     rnd_init() can be called two times without rnd_end() in between
@@ -2089,11 +2122,12 @@
   {
     return 0;
   }
-  virtual void release_auto_increment() { return; };
+  virtual void release_auto_increment(void) { return; };
   /** admin commands - called from mysql_admin_table */
-  virtual int check_for_upgrade(HA_CHECK_OPT *check_opt)
+  virtual int check_for_upgrade(HA_CHECK_OPT *check_opt __attribute__((__unused__)))
   { return 0; }
-  virtual int check(THD* thd, HA_CHECK_OPT* check_opt)
+  virtual int check(THD* thd __attribute__((__unused__)),
+                    HA_CHECK_OPT* check_opt __attribute__((__unused__)))
   { return HA_ADMIN_NOT_IMPLEMENTED; }
 
   /**
@@ -2101,14 +2135,20 @@
      to specify CHECK option to use to call check()
      upon the table.
   */
-  virtual int repair(THD* thd, HA_CHECK_OPT* check_opt)
+  virtual int repair(THD* thd __attribute__((__unused__)),
+                     HA_CHECK_OPT* check_opt __attribute__((__unused__)))
   { return HA_ADMIN_NOT_IMPLEMENTED; }
-  virtual void start_bulk_insert(ha_rows rows) {}
-  virtual int end_bulk_insert() { return 0; }
-  virtual int index_read(uchar * buf, const uchar * key, uint key_len,
-                         enum ha_rkey_function find_flag)
+  virtual void start_bulk_insert(ha_rows rows __attribute__((__unused__)))
+  {}
+  virtual int end_bulk_insert(void) { return 0; }
+  virtual int index_read(uchar * buf __attribute__((__unused__)),
+                         const uchar * key __attribute__((__unused__)),
+                         uint key_len __attribute__((__unused__)),
+                         enum ha_rkey_function find_flag __attribute__((__unused__)))
    { return  HA_ERR_WRONG_COMMAND; }
-  virtual int index_read_last(uchar * buf, const uchar * key, uint key_len)
+  virtual int index_read_last(uchar * buf __attribute__((__unused__)),
+                              const uchar * key __attribute__((__unused__)),
+                              uint key_len __attribute__((__unused__)))
    { return (my_errno= HA_ERR_WRONG_COMMAND); }
   /**
     This method is similar to update_row, however the handler doesn't need
@@ -2123,8 +2163,9 @@
     @retval  0   Bulk delete used by handler
     @retval  1   Bulk delete not used, normal operation used
   */
-  virtual int bulk_update_row(const uchar *old_data, uchar *new_data,
-                              uint *dup_key_found)
+  virtual int bulk_update_row(const uchar *old_data __attribute__((__unused__)),
+                              uchar *new_data __attribute__((__unused__)),
+                              uint *dup_key_found __attribute__((__unused__)))
   {
     DBUG_ASSERT(FALSE);
     return HA_ERR_WRONG_COMMAND;
@@ -2135,7 +2176,7 @@
     return HA_ERR_WRONG_COMMAND and MySQL will delete the rows one
     by one.
   */
-  virtual int delete_all_rows()
+  virtual int delete_all_rows(void)
   { return (my_errno=HA_ERR_WRONG_COMMAND); }
   /**
     Reset the auto-increment counter to the given value, i.e. the next row
@@ -2143,23 +2184,32 @@
     is emulated by doing a 'DELETE FROM t'. HA_ERR_WRONG_COMMAND is
     returned by storage engines that don't support this operation.
   */
-  virtual int reset_auto_increment(uint64_t value)
-  { return HA_ERR_WRONG_COMMAND; }
-  virtual int optimize(THD* thd, HA_CHECK_OPT* check_opt)
-  { return HA_ADMIN_NOT_IMPLEMENTED; }
-  virtual int analyze(THD* thd, HA_CHECK_OPT* check_opt)
-  { return HA_ADMIN_NOT_IMPLEMENTED; }
-  virtual bool check_and_repair(THD *thd) { return TRUE; }
-  virtual int disable_indexes(uint mode) { return HA_ERR_WRONG_COMMAND; }
-  virtual int enable_indexes(uint mode) { return HA_ERR_WRONG_COMMAND; }
-  virtual int discard_or_import_tablespace(my_bool discard)
+  virtual int reset_auto_increment(uint64_t value __attribute__((__unused__)))
+  { return HA_ERR_WRONG_COMMAND; }
+  virtual int optimize(THD* thd __attribute__((__unused__)),
+                       HA_CHECK_OPT* check_opt __attribute__((__unused__)))
+  { return HA_ADMIN_NOT_IMPLEMENTED; }
+  virtual int analyze(THD* thd __attribute__((__unused__)),
+                      HA_CHECK_OPT* check_opt __attribute__((__unused__)))
+  { return HA_ADMIN_NOT_IMPLEMENTED; }
+  virtual bool check_and_repair(THD *thd __attribute__((__unused__)))
+  { return TRUE; }
+  virtual int disable_indexes(uint mode __attribute__((__unused__)))
+  { return HA_ERR_WRONG_COMMAND; }
+  virtual int enable_indexes(uint mode __attribute__((__unused__)))
+  { return HA_ERR_WRONG_COMMAND; }
+  virtual int discard_or_import_tablespace(my_bool discard __attribute__((__unused__)))
   { return (my_errno=HA_ERR_WRONG_COMMAND); }
-  virtual void prepare_for_alter() { return; }
+  virtual void prepare_for_alter(void) { return; }
   virtual void drop_table(const char *name);
-  virtual int create(const char *name, TABLE *form, HA_CREATE_INFO *info)=0;
+  virtual int create(const char *name __attribute__((__unused__)),
+                     TABLE *form __attribute__((__unused__)),
+                     HA_CREATE_INFO *info __attribute__((__unused__)))=0;
 
-  virtual int create_handler_files(const char *name, const char *old_name,
-                                   int action_flag, HA_CREATE_INFO *info)
+  virtual int create_handler_files(const char *name __attribute__((__unused__)),
+                                   const char *old_name __attribute__((__unused__)),
+                                   int action_flag __attribute__((__unused__)),
+                                   HA_CREATE_INFO *info __attribute__((__unused__)))
   { return FALSE; }
 };
 

=== modified file 'sql/item.h'
--- sql/item.h	2008-07-03 12:39:14 +0000
+++ sql/item.h	2008-07-05 23:05:08 +0000
@@ -165,7 +165,8 @@
   virtual void div(Hybrid_type *val, ulonglong u) const
   { val->real/= ulonglong2double(u); }
 
-  virtual longlong val_int(Hybrid_type *val, bool unsigned_flag) const
+  virtual longlong val_int(Hybrid_type *val,
+                           bool unsigned_flag __attribute__((__unused__))) const
   { return (longlong) rint(val->real); }
   virtual double val_real(Hybrid_type *val) const { return val->real; }
   virtual my_decimal *val_decimal(Hybrid_type *val, my_decimal *buf) const;
@@ -190,7 +191,8 @@
 
   virtual longlong val_int(Hybrid_type *val, bool unsigned_flag) const;
   virtual double val_real(Hybrid_type *val) const;
-  virtual my_decimal *val_decimal(Hybrid_type *val, my_decimal *buf) const
+  virtual my_decimal *val_decimal(Hybrid_type *val,
+                                  my_decimal *buf __attribute__((__unused__))) const
   { return &val->dec_buf[val->used_dec_buf_no]; }
   virtual String *val_str(Hybrid_type *val, String *buf, uint8 decimals) const;
   static const Hybrid_type_traits_decimal *instance();
@@ -213,16 +215,19 @@
   virtual void div(Hybrid_type *val, ulonglong u) const
   { val->integer/= (longlong) u; }
 
-  virtual longlong val_int(Hybrid_type *val, bool unsigned_flag) const
+  virtual longlong val_int(Hybrid_type *val,
+                           bool unsigned_flag __attribute__((__unused__))) const
   { return val->integer; }
   virtual double val_real(Hybrid_type *val) const
   { return (double) val->integer; }
-  virtual my_decimal *val_decimal(Hybrid_type *val, my_decimal *buf) const
+  virtual my_decimal *val_decimal(Hybrid_type *val,
+                                  my_decimal *buf __attribute__((__unused__))) const
   {
     int2my_decimal(E_DEC_FATAL_ERROR, val->integer, 0, &val->dec_buf[2]);
     return &val->dec_buf[2];
   }
-  virtual String *val_str(Hybrid_type *val, String *buf, uint8 decimals) const
+  virtual String *val_str(Hybrid_type *val, String *buf,
+                          uint8 decimals __attribute__((__unused__))) const
   { buf->set(val->integer, &my_charset_bin); return buf;}
   static const Hybrid_type_traits_integer *instance();
   Hybrid_type_traits_integer() {};
@@ -430,15 +435,20 @@
   void operator=(Item &);
   /* Cache of the result of is_expensive(). */
   int8 is_expensive_cache;
-  virtual bool is_expensive_processor(uchar *arg) { return 0; }
+  virtual bool is_expensive_processor(uchar *arg __attribute__((__unused__)))
+  { return 0; }
 
 public:
   static void *operator new(size_t size)
   { return sql_alloc(size); }
   static void *operator new(size_t size, MEM_ROOT *mem_root)
   { return alloc_root(mem_root, size); }
-  static void operator delete(void *ptr,size_t size) { TRASH(ptr, size); }
-  static void operator delete(void *ptr, MEM_ROOT *mem_root) {}
+  static void operator delete(void *ptr __attribute__((__unused__)),
+                              size_t size __attribute__((__unused__)))
+  { TRASH(ptr, size); }
+  static void operator delete(void *ptr __attribute__((__unused__)),
+                              MEM_ROOT *mem_root __attribute__((__unused__)))
+  {}
 
   enum Type {FIELD_ITEM= 0, FUNC_ITEM, SUM_FUNC_ITEM, STRING_ITEM,
 	     INT_ITEM, REAL_ITEM, NULL_ITEM, VARBIN_ITEM,
@@ -510,7 +520,8 @@
     Fix after some tables has been pulled out. Basically re-calculate all
     attributes that are dependent on the tables.
   */
-  virtual void fix_after_pullout(st_select_lex *new_parent, Item **ref) {};
+  virtual void fix_after_pullout(st_select_lex *new_parent __attribute__((__unused__)),
+                                 Item **ref __attribute__((__unused__))) {};
 
   /*
     should be used in case where we are sure that we do not need
@@ -570,10 +581,11 @@
 
     RETURN
       The output range bound, which equal to the value of val_int()
-        - If the value of the function is NULL then the bound is the 
-          smallest possible value of LONGLONG_MIN 
+        - If the value of the function is NULL then the bound is the
+          smallest possible value of LONGLONG_MIN
   */
-  virtual longlong val_int_endpoint(bool left_endp, bool *incl_endp)
+  virtual longlong val_int_endpoint(bool left_endp __attribute__((__unused__)),
+                                    bool *incl_endp __attribute__((__unused__)))
   { DBUG_ASSERT(0); return 0; }
 
 
@@ -684,10 +696,11 @@
   int save_date_in_field(Field *field);
   int save_str_value_in_field(Field *field, String *result);
 
-  virtual Field *get_tmp_table_field() { return 0; }
+  virtual Field *get_tmp_table_field(void) { return 0; }
   /* This is also used to create fields in CREATE ... SELECT: */
-  virtual Field *tmp_table_field(TABLE *t_arg) { return 0; }
-  virtual const char *full_name() const { return name ? name : "???"; }
+  virtual Field *tmp_table_field(TABLE *t_arg __attribute__((__unused__)))
+  { return 0; }
+  virtual const char *full_name(void) const { return name ? name : "???"; }
 
   /*
     *result* family of methods is analog of *val* family (see above) but
@@ -752,15 +765,17 @@
     query and why they should be generated from the Item-tree, @see
     mysql_register_view().
   */
-  virtual inline void print(String *str, enum_query_type query_type)
+  virtual inline void print(String *str,
+                            enum_query_type query_type __attribute__((__unused__)))
   {
     str->append(full_name());
   }
 
   void print_item_w_name(String *, enum_query_type query_type);
   virtual void update_used_tables() {}
-  virtual void split_sum_func(THD *thd, Item **ref_pointer_array,
-                              List<Item> &fields) {}
+  virtual void split_sum_func(THD *thd __attribute__((__unused__)),
+                              Item **ref_pointer_array __attribute__((__unused__)),
+                              List<Item> &fields __attribute__((__unused__))) {}
   /* Called for items that really have to be split */
   void split_sum_func2(THD *thd, Item **ref_pointer_array, List<Item> &fields,
                        Item **ref, bool skip_registered);
@@ -792,28 +807,33 @@
       Item_cond_and and subquery-related item) enable special optimizations
       when they are "top level".
   */
-  virtual void top_level_item() {}
+  virtual void top_level_item(void) {}
   /*
     set field of temporary table for Item which can be switched on temporary
     table during query processing (grouping and so on)
   */
-  virtual void set_result_field(Field *field) {}
-  virtual bool is_result_field() { return 0; }
-  virtual bool is_bool_func() { return 0; }
-  virtual void save_in_result_field(bool no_conversions) {}
+  virtual void set_result_field(Field *field __attribute__((__unused__))) {}
+  virtual bool is_result_field(void) { return 0; }
+  virtual bool is_bool_func(void) { return 0; }
+  virtual void save_in_result_field(bool no_conversions __attribute__((__unused__)))
+  {}
   /*
     set value of aggregate function in case of no rows for grouping were found
   */
-  virtual void no_rows_in_result() {}
-  virtual Item *copy_or_same(THD *thd) { return this; }
-  virtual Item *copy_andor_structure(THD *thd) { return this; }
-  virtual Item *real_item() { return this; }
+  virtual void no_rows_in_result(void) {}
+  virtual Item *copy_or_same(THD *thd __attribute__((__unused__)))
+  { return this; }
+  virtual Item *copy_andor_structure(THD *thd  __attribute__((__unused__)))
+  { return this; }
+  virtual Item *real_item(void) { return this; }
   virtual Item *get_tmp_table_item(THD *thd) { return copy_or_same(thd); }
 
   static CHARSET_INFO *default_charset();
   virtual CHARSET_INFO *compare_collation() { return NULL; }
 
-  virtual bool walk(Item_processor processor, bool walk_subquery, uchar *arg)
+  virtual bool walk(Item_processor processor __attribute__((__unused__)),
+                    bool walk_subquery __attribute__((__unused__)),
+                    uchar *arg)
   {
     return (this->*processor)(arg);
   }
@@ -844,48 +864,59 @@
     return 0;
   }
 
-   virtual void traverse_cond(Cond_traverser traverser,
-                              void *arg, traverse_order order)
+   virtual void traverse_cond(Cond_traverser traverser __attribute__((__unused__)),
+                              void *arg,
+                              traverse_order order __attribute__((__unused__)))
    {
      (*traverser)(this, arg);
    }
 
-  virtual bool remove_dependence_processor(uchar * arg) { return 0; }
-  virtual bool remove_fixed(uchar * arg) { fixed= 0; return 0; }
-  virtual bool cleanup_processor(uchar *arg);
-  virtual bool collect_item_field_processor(uchar * arg) { return 0; }
-  virtual bool find_item_in_field_list_processor(uchar *arg) { return 0; }
-  virtual bool change_context_processor(uchar *context) { return 0; }
-  virtual bool reset_query_id_processor(uchar *query_id_arg) { return 0; }
-  virtual bool register_field_in_read_map(uchar *arg) { return 0; }
+  virtual bool remove_dependence_processor(uchar * arg __attribute__((__unused__)))
+  { return 0; }
+  virtual bool remove_fixed(uchar * arg __attribute__((__unused__)))
+  {
+    fixed= 0;
+    return 0;
+  }
+  virtual bool cleanup_processor(uchar *arg __attribute__((__unused__)));
+  virtual bool collect_item_field_processor(uchar * arg __attribute__((__unused__)))
+  { return 0; }
+  virtual bool find_item_in_field_list_processor(uchar *arg __attribute__((__unused__)))
+ { return 0; }
+  virtual bool change_context_processor(uchar *context __attribute__((__unused__)))
+  { return 0; }
+  virtual bool reset_query_id_processor(uchar *query_id_arg __attribute__((__unused__)))
+  { return 0; }
+  virtual bool register_field_in_read_map(uchar *arg __attribute__((__unused__)))
+  { return 0; }
   virtual bool subst_argument_checker(uchar **arg)
-  { 
+  {
     if (*arg)
-      *arg= NULL; 
-    return TRUE;     
+      *arg= NULL;
+    return true;
   }
 
-  virtual Item *equal_fields_propagator(uchar * arg) { return this; }
-  virtual bool set_no_const_sub(uchar *arg) { return FALSE; }
-  virtual Item *replace_equal_field(uchar * arg) { return this; }
+  virtual Item *equal_fields_propagator(uchar * arg __attribute__((__unused__))) { return this; }
+  virtual bool set_no_const_sub(uchar *arg __attribute__((__unused__))) { return false; }
+  virtual Item *replace_equal_field(uchar * arg __attribute__((__unused__))) { return this; }
 
   /*
     For SP local variable returns pointer to Item representing its
     current value and pointer to current Item otherwise.
   */
-  virtual Item *this_item() { return this; }
-  virtual const Item *this_item() const { return this; }
+  virtual Item *this_item(void) { return this; }
+  virtual const Item *this_item(void) const { return this; }
 
   /*
     For SP local variable returns address of pointer to Item representing its
     current value and pointer passed via parameter otherwise.
   */
-  virtual Item **this_item_addr(THD *thd, Item **addr_arg) { return addr_arg; }
+  virtual Item **this_item_addr(THD *thd __attribute__((__unused__)), Item **addr_arg) { return addr_arg; }
 
   // Row emulation
   virtual uint cols() { return 1; }
-  virtual Item* element_index(uint i) { return this; }
-  virtual Item** addr(uint i) { return 0; }
+  virtual Item* element_index(uint i __attribute__((__unused__))) { return this; }
+  virtual Item** addr(uint i __attribute__((__unused__))) { return 0; }
   virtual bool check_cols(uint c);
   // It is not row => null inside is impossible
   virtual bool null_inside() { return 0; }
@@ -895,8 +926,8 @@
   Field *tmp_table_field_from_field_type(TABLE *table, bool fixed_length);
   virtual Item_field *filed_for_view_update() { return 0; }
 
-  virtual Item *neg_transformer(THD *thd) { return NULL; }
-  virtual Item *update_value_transformer(uchar *select_arg) { return this; }
+  virtual Item *neg_transformer(THD *thd __attribute__((__unused__))) { return NULL; }
+  virtual Item *update_value_transformer(uchar *select_arg __attribute__((__unused__))) { return this; }
   virtual Item *safe_charset_converter(CHARSET_INFO *tocs);
   void delete_self()
   {
@@ -1115,7 +1146,7 @@
   }
   longlong val_int_endpoint(bool left_endp, bool *incl_endp);
   Field *get_tmp_table_field() { return result_field; }
-  Field *tmp_table_field(TABLE *t_arg) { return result_field; }
+  Field *tmp_table_field(TABLE *t_arg __attribute__((__unused__))) { return result_field; }
   bool get_date(MYSQL_TIME *ltime,uint fuzzydate);
   bool get_date_result(MYSQL_TIME *ltime,uint fuzzydate);
   bool get_time(MYSQL_TIME *ltime);
@@ -1179,7 +1210,8 @@
   Item *clone_item() { return new Item_null(name); }
   bool is_null() { return 1; }
 
-  virtual inline void print(String *str, enum_query_type query_type)
+  virtual inline void print(String *str,
+                            enum_query_type query_type __attribute__((__unused__)))
   {
     str->append(STRING_WITH_LEN("NULL"));
   }
@@ -1411,7 +1443,8 @@
   longlong val_int();
   double val_real();
   String *val_str(String*);
-  my_decimal *val_decimal(my_decimal *val) { return &decimal_value; }
+  my_decimal *val_decimal(my_decimal *val __attribute__((__unused__)))
+  { return &decimal_value; }
   int save_in_field(Field *field, bool no_conversions);
   bool basic_const_item() const { return 1; }
   Item *clone_item()
@@ -1488,7 +1521,8 @@
     :Item_float(NullS, val_arg, decimal_par, length), func_name(str)
   {}
 
-  virtual inline void print(String *str, enum_query_type query_type)
+  virtual inline void print(String *str,
+                            enum_query_type query_type __attribute__((__unused__)))
   {
     str->append(func_name);
   }
@@ -1640,7 +1674,8 @@
   {}
   Item *safe_charset_converter(CHARSET_INFO *tocs);
 
-  virtual inline void print(String *str, enum_query_type query_type)
+  virtual inline void print(String *str,
+                            enum_query_type query_type __attribute__((__unused__)))
   {
     str->append(func_name);
   }
@@ -1743,7 +1778,8 @@
   {}
   ~Item_result_field() {}			/* Required with gcc 2.95 */
   Field *get_tmp_table_field() { return result_field; }
-  Field *tmp_table_field(TABLE *t_arg) { return result_field; }
+  Field *tmp_table_field(TABLE *t_arg __attribute__((__unused__)))
+  { return result_field; }
   table_map used_tables() const { return 1; }
   virtual void fix_length_and_dec()=0;
   void set_result_field(Field *field) { result_field= field; }
@@ -1976,7 +2012,7 @@
                      alias_name_used_arg),
     outer_ref(0), in_sum_func(0), found_in_select_list(1)
   {}
-  void save_in_result_field(bool no_conversions)
+  void save_in_result_field(bool no_conversions __attribute__((__unused__)))
   {
     outer_ref->save_org_in_field(result_field);
   }
@@ -2101,7 +2137,8 @@
   my_decimal *val_decimal(my_decimal *);
   void make_field(Send_field *field) { item->make_field(field); }
   void copy();
-  int save_in_field(Field *field, bool no_conversions)
+  int save_in_field(Field *field,
+                    bool no_conversions __attribute__((__unused__)))
   {
     return save_str_value_in_field(field, &str_value);
   }
@@ -2285,7 +2322,8 @@
 
   void set_used_tables(table_map map) { used_table_map= map; }
 
-  virtual bool allocate(uint i) { return 0; }
+  virtual bool allocate(uint i __attribute__((__unused__)))
+  { return 0; }
   virtual bool setup(Item *item)
   {
     example= item;
@@ -2308,7 +2346,8 @@
   { 
     return cached_field ? cached_field->eq_def (field) : FALSE;
   }
-  bool eq(const Item *item, bool binary_cmp) const
+  bool eq(const Item *item,
+          bool binary_cmp __attribute__((__unused__))) const
   {
     return this == item;
   }
@@ -2430,7 +2469,7 @@
     illegal_method_call((const char*)"val_str");
     return 0;
   };
-  my_decimal *val_decimal(my_decimal *val)
+  my_decimal *val_decimal(my_decimal *val __attribute__((__unused__)))
   {
     illegal_method_call((const char*)"val_decimal");
     return 0;

=== modified file 'sql/log.h'
--- sql/log.h	2008-06-25 05:29:13 +0000
+++ sql/log.h	2008-07-05 23:05:08 +0000
@@ -41,10 +41,13 @@
 {
 public:
   TC_LOG_DUMMY() {}
-  int open(const char *opt_name)        { return 0; }
-  void close()                          { }
-  int log_xid(THD *thd, my_xid xid)         { return 1; }
-  void unlog(ulong cookie, my_xid xid)  { }
+  int open(const char *opt_name __attribute__((__unused__)))
+  { return 0; }
+  void close(void)                          { }
+  int log_xid(THD *thd __attribute__((__unused__)),
+              my_xid xid __attribute__((__unused__)))         { return 1; }
+  void unlog(ulong cookie __attribute__((__unused__)),
+             my_xid xid __attribute__((__unused__)))  { }
 };
 
 #ifdef HAVE_MMAP

=== modified file 'sql/sql_list.h'
--- sql/sql_list.h	2008-06-25 05:29:13 +0000
+++ sql/sql_list.h	2008-07-05 23:05:08 +0000
@@ -37,12 +37,18 @@
   { return alloc_root(mem_root, size); }
   static void *operator new(size_t size, MEM_ROOT *mem_root) throw ()
   { return alloc_root(mem_root, size); }
-  static void operator delete(void *ptr, size_t size) { TRASH(ptr, size); }
-  static void operator delete(void *ptr, MEM_ROOT *mem_root)
-  { /* never called */ }
-  static void operator delete[](void *ptr, MEM_ROOT *mem_root)
-  { /* never called */ }
-  static void operator delete[](void *ptr, size_t size) { TRASH(ptr, size); }
+  static void operator delete(void *ptr __attribute__((__unused__)),
+                              size_t size __attribute__((__unused__)))
+  { TRASH(ptr, size); }
+  static void operator delete(void *ptr __attribute__((__unused__)),
+                              MEM_ROOT *mem_root __attribute__((__unused__)))
+  { /* never called */ }
+  static void operator delete[](void *ptr __attribute__((__unused__)),
+                                MEM_ROOT *mem_root __attribute__((__unused__)))
+  { /* never called */ }
+  static void operator delete[](void *ptr __attribute__((__unused__)),
+                                size_t size __attribute__((__unused__)))
+  { TRASH(ptr, size); }
 #ifdef HAVE_purify
   bool dummy;
   inline Sql_alloc() :dummy(0) {}
@@ -120,7 +126,7 @@
     list_copy_and_replace_each_value after creating a copy.
   */
   base_list(const base_list &rhs, MEM_ROOT *mem_root);
-  inline base_list(bool error) { }
+  inline base_list(bool error __attribute__((__unused__))) { }
   inline bool push_back(void *info)
   {
     if (((*last)=new list_node(info, &end_of_list)))
@@ -454,7 +460,8 @@
   {
     return (void*)my_malloc((uint)size, MYF(MY_WME | MY_FAE | ME_FATALERROR));
   }
-  static void operator delete(void* ptr_arg, size_t size)
+  static void operator delete(void* ptr_arg,
+                              size_t size __attribute__((__unused__)))
   {
      my_free((uchar*)ptr_arg, MYF(MY_WME|MY_ALLOW_ZERO_PTR));
   }

=== modified file 'sql/sql_string.h'
--- sql/sql_string.h	2008-06-25 05:29:13 +0000
+++ sql/sql_string.h	2008-07-05 23:05:08 +0000
@@ -81,9 +81,11 @@
   }
   static void *operator new(size_t size, MEM_ROOT *mem_root)
   { return (void*) alloc_root(mem_root, (uint) size); }
-  static void operator delete(void *ptr_arg,size_t size)
+  static void operator delete(void *ptr_arg __attribute__((__unused__)),
+                              size_t size __attribute__((__unused__)))
   { TRASH(ptr_arg, size); }
-  static void operator delete(void *ptr_arg, MEM_ROOT *mem_root)
+  static void operator delete(void *ptr_arg __attribute__((__unused__)),
+                              MEM_ROOT *mem_root __attribute__((__unused__)))
   { /* never called */ }
   ~String() { free(); }
 

=== modified file 'sql/table.h'
--- sql/table.h	2008-07-04 13:45:27 +0000
+++ sql/table.h	2008-07-05 23:05:08 +0000
@@ -1196,22 +1196,16 @@
 
 /* The following is only needed for debugging */
 
-static inline my_bitmap_map *dbug_tmp_use_all_columns(TABLE *table,
-                                                      MY_BITMAP *bitmap)
+static inline my_bitmap_map *dbug_tmp_use_all_columns(TABLE *table __attribute__((__unused__)),
+                                                      MY_BITMAP *bitmap __attribute__((__unused__)))
 {
-#ifndef DBUG_OFF
-  return tmp_use_all_columns(table, bitmap);
-#else
   return 0;
-#endif
 }
 
-static inline void dbug_tmp_restore_column_map(MY_BITMAP *bitmap,
-                                               my_bitmap_map *old)
+static inline void dbug_tmp_restore_column_map(MY_BITMAP *bitmap __attribute__((__unused__)),
+                                               my_bitmap_map *old __attribute__((__unused__)))
 {
-#ifndef DBUG_OFF
-  tmp_restore_column_map(bitmap, old);
-#endif
+  return;
 }
 
 size_t max_row_length(TABLE *table, const uchar *data);

=== modified file 'storage/archive/ha_archive.cc'
--- storage/archive/ha_archive.cc	2008-07-04 13:45:27 +0000
+++ storage/archive/ha_archive.cc	2008-07-05 23:05:08 +0000
@@ -201,7 +201,7 @@
     FALSE       OK
 */
 
-int archive_db_done(void *p)
+int archive_db_done(void *p __attribute__((__unused__)))
 {
   hash_free(&archive_open_tables);
   VOID(pthread_mutex_destroy(&archive_mutex));
@@ -221,9 +221,11 @@
   archive_reader_open= FALSE;
 }
 
-int archive_discover(handlerton *hton, THD* thd, const char *db, 
+int archive_discover(handlerton *hton __attribute__((__unused__)),
+                     THD* thd __attribute__((__unused__)),
+                     const char *db,
                      const char *name,
-                     uchar **frmblob, 
+                     uchar **frmblob,
                      size_t *frmlen)
 {
   DBUG_ENTER("archive_discover");
@@ -484,7 +486,9 @@
   Init out lock.
   We open the file we will read from.
 */
-int ha_archive::open(const char *name, int mode, uint open_options)
+int ha_archive::open(const char *name,
+                     int mode __attribute__((__unused__)),
+                     uint open_options)
 {
   int rc= 0;
   DBUG_ENTER("ha_archive::open");
@@ -731,7 +735,7 @@
   the bytes required for the length in the header.
 */
 
-uint32 ha_archive::max_row_length(const uchar *buf)
+uint32 ha_archive::max_row_length(const uchar *buf __attribute__((__unused__)))
 {
   uint32 length= (uint32)(table->s->reclength + table->s->fields*2);
   length+= ARCHIVE_ROW_HEADER_SIZE;
@@ -890,17 +894,18 @@
 }
 
 
-void ha_archive::get_auto_increment(uint64_t offset, uint64_t increment,
-                                    uint64_t nb_desired_values,
-                                    uint64_t *first_value,
-                                    uint64_t *nb_reserved_values)
+void ha_archive::get_auto_increment(uint64_t offset __attribute__((__unused__)),
+                                    uint64_t increment __attribute__((__unused__)),
+                                    uint64_t nb_desired_values __attribute__((__unused__)),
+                                    uint64_t *first_value __attribute__((__unused__)),
+                                    uint64_t *nb_reserved_values __attribute__((__unused__)))
 {
   *nb_reserved_values= ULONGLONG_MAX;
   *first_value= share->archive_write.auto_increment + 1;
 }
 
 /* Initialized at each key walk (called multiple times unlike rnd_init()) */
-int ha_archive::index_init(uint keynr, bool sorted)
+int ha_archive::index_init(uint keynr, bool sorted __attribute__((__unused__)))
 {
   DBUG_ENTER("ha_archive::index_init");
   active_index= keynr;
@@ -923,7 +928,8 @@
 
 
 int ha_archive::index_read_idx(uchar *buf, uint index, const uchar *key,
-                                 uint key_len, enum ha_rkey_function find_flag)
+                               uint key_len,
+                               enum ha_rkey_function find_flag __attribute__((__unused__)))
 {
   int rc;
   bool found= 0;
@@ -1122,7 +1128,7 @@
   needed.
 */
 
-void ha_archive::position(const uchar *record)
+void ha_archive::position(const uchar *record __attribute__((__unused__)))
 {
   DBUG_ENTER("ha_archive::position");
   my_store_ptr(ref, ref_length, current_position);
@@ -1169,7 +1175,8 @@
   The table can become fragmented if data was inserted, read, and then
   inserted again. What we do is open up the file and recompress it completely. 
 */
-int ha_archive::optimize(THD* thd, HA_CHECK_OPT* check_opt)
+int ha_archive::optimize(THD* thd __attribute__((__unused__)),
+                         HA_CHECK_OPT* check_opt __attribute__((__unused__)))
 {
   DBUG_ENTER("ha_archive::optimize");
   int rc= 0;
@@ -1460,7 +1467,8 @@
   Simple scan of the tables to make sure everything is ok.
 */
 
-int ha_archive::check(THD* thd, HA_CHECK_OPT* check_opt)
+int ha_archive::check(THD* thd,
+                      HA_CHECK_OPT* check_opt __attribute__((__unused__)))
 {
   int rc= 0;
   const char *old_proc_info;

=== modified file 'storage/archive/ha_archive.h'
--- storage/archive/ha_archive.h	2008-06-25 05:29:13 +0000
+++ storage/archive/ha_archive.h	2008-07-05 23:05:08 +0000
@@ -84,7 +84,8 @@
   {
   }
   const char *table_type() const { return "ARCHIVE"; }
-  const char *index_type(uint inx) { return "NONE"; }
+  const char *index_type(uint inx __attribute__((__unused__)))
+  { return "NONE"; }
   const char **bas_ext() const;
   uint64_t table_flags() const
   {
@@ -94,7 +95,9 @@
             HA_HAS_RECORDS |
             HA_FILE_BASED | HA_CAN_INSERT_DELAYED | HA_CAN_GEOMETRY);
   }
-  ulong index_flags(uint idx, uint part, bool all_parts) const
+  ulong index_flags(uint idx __attribute__((__unused__)),
+                    uint part __attribute__((__unused__)),
+                    bool all_parts __attribute__((__unused__))) const
   {
     return HA_ONLY_WHOLE_INDEX;
   }

